-- 道具获得提示
Lua_ObtainItemTipsWindow = class("Lua_ObtainItemTipsWindow", Lua_Window);
function Lua_ObtainItemTipsWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_ObtainItemTipsWindow";
    self.showBlackMask = true;
    self.showWinBg = true;
    self.winBgPath = "/images/common/ui_common_window_024.png";
    self.winBgPosY = 31;
    self.openSound = "obtain_item_01";
    self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
    self.showParams = Array();
end

function Lua_ObtainItemTipsWindow:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_ObtainItemTipsWindow:showWin(param)
    self:superCall("showWin", param);
    if param == nil and (param.data == nil or param.data:getSize() <= 0) then
        if self:checkShowOrHide() == false then
            self:hide();
        end
        return;
    end
    
    self.showParams:add(param);
    if self.bTiming == true then
        return;
    end

    self:showNextInfo();
end

function Lua_ObtainItemTipsWindow:checkShowOrHide()
    if self.bTiming == true then
        return true;
    end

    if self.showParams == nil or self.showParams:getSize() <= 0 then
        return false;
    end
    return true;
end

function Lua_ObtainItemTipsWindow:showNextInfo()
    if self.showParams == nil then
        self:hide();
        return;
    end

    while (self.showParams:getSize() > 0) do
        self.param = self.showParams:shift();
        if self.param ~= nil then
            break;
        end
    end

    if self.param == nil then
        self:hide();
        return;
    end

    local data = self.param.data;
    if data == nil then
        data = self.param;
    end
    local len = data:getSize();
    local size = 112;
    local width;
    local height;
    local interval = 10;
    if len > 5 then
        width = 600;
        height = 234;
    else
        width = size * len + interval * (len - 1);
        height = size;
    end

    if self.itemList == nil then
        self.itemList = Lua_DragList.new(self.content, width, height, Lua_AxisDefine.Vertical);
        self.itemList:setLocation(0, -20, 0);
        self.itemList:setListCell(Lua_ItemIconCell, size, size, 5);
        self.itemList:setCellSpacing(interval, interval);
    else
        self.itemList:setContentRect(width, height);
    end
    self.itemList.canDrag = len > 5;
    self.itemList:setScale(0.1, 0.1, 0.1);
    self.itemList:setArrayData(data);

    self.startTime = getTime();
    self:startTimer();
end

function Lua_ObtainItemTipsWindow:startTimer()
    if self.bTiming == nil or self.bTiming == false then
        self.bTiming = true;
        self:addTimer("Lua_ObtainItemTipsWindow", 0.01, self, self.onTimer, nil, -1);
    end
end

function Lua_ObtainItemTipsWindow:endTimer()
    if self.bTiming ~= nil and self.bTiming == true then
        self.bTiming = false;
        self.isClickClose = true;
        self:createCloseTips(0, -286, 0);
        self:removeTimer(self, self.onTimer);
    end
end

function Lua_ObtainItemTipsWindow:onTimer()
    local dt = getTime() - self.startTime;
    if dt > 0.03 then
        local scaleCoun = dt * 4;
        if scaleCoun >= 1 then
            self:endTimer();
            self.itemList:setScale(1, 1, 1);
        else
            self.itemList:setScale(scaleCoun, scaleCoun, 1);
        end
    end
end

function Lua_ObtainItemTipsWindow:onMaskClick(go)
    if self.isClickClose == true then
        if self.param.data ~= nil then
            self.param.data = nil;
        end
        if self.param.owner ~= nil then
            if self.param.cancelFun ~= nil then
                self.param.cancelFun(self.param.owner, self.param);
            end
            self.param.owner = nil;
            self.param.cancelFun = nil;
            self.param = nil;
        end
        self.param = nil;

        self:showNextInfo();
    end
end

function Lua_ObtainItemTipsWindow:dispose()
    self:endTimer();
    if self.itemList ~= nil then
        self.itemList:dispose();
        self.itemList = nil;
    end
    if self.param ~= nil then
        if self.param.owner ~= nil then
            self.param.owner = nil;
            self.param.cancelFun = nil;
            self.param = nil;
        end
        if self.param.data ~= nil then
            self.param.data = nil;
        end
        self.param = nil;
    end
    if self.showParams ~= nil then
        while (self.showParams:getSize() > 0) do
            self.param = self.showParams:shift();
            if self.param ~= nil then
                if self.param.owner ~= nil then
                    self.param.owner = nil;
                    self.param.cancelFun = nil;
                    self.param = nil;
                end
                if self.param.data ~= nil then
                    self.param.data = nil;
                end
                self.param = nil;
            end
        end
        self.showParams:dispose();
        self.showParams:clear();
        self.showParams = nil;
    end
    self:superCall("dispose");
end