Lua_PackBatchWindow = class("Lua_PackBatchWindow", Lua_Window);
function Lua_PackBatchWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_PackBatchWindow";
    self.skinName = "PackBatchWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
end

function Lua_PackBatchWindow:buildShowItem()
    self:superCall("buildShowItem");
    self.selectedDic = {};
    self.selectedArr = Array();

    self:addLuaEvent("PACK_FILTER", self, self.updateFilterDic);
    self:addLuaEvent("PACK_BATCH_PLUS", self, self.onItemPlus);
    self:addLuaEvent("PACK_BATCH_LESS", self, self.onItemLess);

    self.itemList = Lua_DragList.new(self.content, 620, 380, Lua_AxisDefine.Vertical);
    self.itemList:setLocation(0, 154, 0);
    self.itemList.canLongPress = true;
    self.itemList.customParam = self.selectedDic;
    self.itemList:setListCell(Lua_PackBatchItem, 112, 140, 5);
    self.itemList:setCellSpacing(15, 0);

    self.getList = Lua_DragList.new(self.content, 620, 112, Lua_AxisDefine.Horizontal);
    self.getList:setLocation(0, -225, 0);
    self.getList:setListCell(Lua_ItemIconCell, 112, 112, 1);
    self.getList:setCellSpacing(5, 0);

    self.filterText:setEnable(false)
    self.btnFilter:setEnable(false)
    self.btnFilter:addClickFuntion(self, self.onBtnFilterClick);
    self.checkHelp:addClickFuntion(self, self.onCheckHelp);
    self.btnOneKey:addClickFuntion(self, self.onBtnOneKeyClick);
    self.btnFunc:addClickFuntion(self, self.onBtnFuncClick);
end

function Lua_PackBatchWindow:dispose()
    if self.itemList ~= nil then
        self.itemList:dispose();
        self.itemList = nil;
    end
    if self.getList ~= nil then
        self.getList:dispose();
        self.getList = nil;
    end
    if self.itemArr ~= nil then
        self.itemArr:clear();
        self.itemArr = nil;
    end
    if self.tvoArr ~= nil then
        self.tvoArr:clear();
        self.tvoArr = nil;
    end
    if self.selectedArr ~= nil then
        self.selectedArr:clear();
        self.selectedArr = nil;
    end
    self.selectedDic = nil;
    self.filterDic = nil;
    self:superCall("dispose");
end

function Lua_PackBatchWindow:showWin(param)
    self:superCall("showWin", param);

    if param.batchType == 1 then -- 分解
        if param.packType == Lua_PackDefine.TYPE_CHIP then
            self.titleName:setAltas("pack_atlas", "ui_bb_title_05");
        else
            self.titleName:setAltas("pack_atlas", "ui_bb_title_03");
        end
        self.btnFunc:setLangValue(309013);
    elseif param.batchType == 2 then -- 出售
        self.titleName:setAltas("pack_atlas", "ui_bb_title_06");
        self.btnFunc:setLangValue(309014);
    end

    self:updateFilterDic();
end

function Lua_PackBatchWindow:updateFilterDic(filterDic)
    self.filterDic = filterDic;
    self:updateListInfo(filterDic);
end

function Lua_PackBatchWindow:updateListInfo(filterDic)
    self.itemArr = nil;
    local packType = self.showData.packType;
    local batchType = self.showData.batchType;
    if packType == Lua_PackDefine.TYPE_RUNSE then
        self.itemArr = DataCenter.runesData:getBatchArrByFilter(batchType, filterDic);
    else
        self.itemArr = DataCenter.packData:getBatchArrByFilter(packType, batchType, filterDic);
    end

    self.itemList:setArrayData(self.itemArr);
    self:showNone(self.itemArr == nil or self.itemArr:getSize() <= 0);
    self.totalCount = self:getTotalCount(self.itemArr);
    self.selectedCount = 0;
    self:updateFilterList();
end

function Lua_PackBatchWindow:showNone(bShow)
    if bShow then
        if self.noneIcon == nil then
            self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, 153, 648, 119);
            self.noneIcon:setScale(0.8, 0.8, 0.8);
        end
        self.noneIcon:setEnable(true);

        if self.noneText == nil then
            self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(309000), 0, 153, 100, 40, 30);
            self.noneText.pivot = UIUtils.Pivot.Center;
            self.noneText.fontName = Lua_MyUISettings.huakangFontName;
            self.noneText.alignmentValue = 4;
            self.noneText.horizontalOverflowValue = 1;
            self.noneText.colorStr = Lua_ColorDefine.transColorStr("9F928C");
        end
        self.noneText:setEnable(true);
    else
        if self.noneIcon ~= nil then
            self.noneIcon:setEnable(false);
        end
        if self.noneText ~= nil then
            self.noneText:setEnable(false);
        end
    end
end

function Lua_PackBatchWindow:getTotalCount(arr)
    local count = 0;
    if arr ~= nil then
        for i = 1, arr:getSize() do
            count = count + arr[i].count;
        end
    end
    return count;
end

function Lua_PackBatchWindow:onItemPlus(data)
    if self.selectedDic[data.unique_id] == nil then
        self.selectedDic[data.unique_id] = 1;
        self.selectedArr:add(data.unique_id);
    else
        local count = self.selectedDic[data.unique_id] + 1;
        if count >= data.count then
            count = data.count;
        end
        self.selectedDic[data.unique_id] = count;
    end

    self:updateShowList();
    self:updateGetList();
end

function Lua_PackBatchWindow:onItemLess(data)
    if self.selectedDic[data.unique_id] == nil then
        return;
    end

    local count = self.selectedDic[data.unique_id] - 1;
    self.selectedDic[data.unique_id] = count;
    if count <= 0 then
        self.selectedDic[data.unique_id] = nil;
        self.selectedArr:removeItem(data.unique_id);
    end

    self:updateShowList();
    self:updateGetList();
end

function Lua_PackBatchWindow:updateFilterList()
    if self.filterDic == nil then
        return;
    end

    local tvo;
    if self.showData.packType == Lua_PackDefine.TYPE_RUNSE then
        for k,v in pairs(self.selectedDic) do
            tvo = DataCenter.runesData:getRunesVoByUid(k);
            if not DataCenter.packData:checkVoIsMeetFilter(self.filterDic, tvo) then
                self.selectedDic[k] = nil;
                self.selectedArr:removeItem(k);
            end
        end
    else
        for k,v in pairs(self.selectedDic) do
            tvo = DataCenter.packData:getItemVoByUnId(k);
            if not DataCenter.packData:checkVoIsMeetFilter(self.filterDic, tvo) then
                self.selectedDic[k] = nil;
                self.selectedArr:removeItem(k);
            end
        end
    end

    self:updateShowList();
    self:updateGetList();
end

function Lua_PackBatchWindow:updateShowList()
    local showList = self.itemList.showList;
    for i = 1, showList:getSize() do
        showList[i]:updateSelected();
    end

    self.selectedCount = self:getSelectedCount();
    self.selectedText.text = LanUtil.formateStr(309040, tostring(self.selectedCount));
    if self.selectedCount > 0 and self.selectedCount >= self.totalCount then
        self.btnOneKey:setLangValue(309064);
    else
        self.btnOneKey:setLangValue(309063);
    end
end

function Lua_PackBatchWindow:getSelectedCount()
    local count = 0;
    local uniqueId;
    for i = 1, self.selectedArr:getSize() do
        uniqueId = self.selectedArr[i];
        count = count + self.selectedDic[uniqueId];
    end
    return count;
end

function Lua_PackBatchWindow:updateGetList()
    local dic = {};
    if self.tvoArr == nil then
        self.tvoArr = Array();
    end
    local len = self.selectedArr:getSize();
    local uniqueId;
    local count;
    local tvo;
    local getVo;
    for i = 1, len do
        uniqueId = self.selectedArr[i];
        count = self.selectedDic[uniqueId] == nil and 0 or self.selectedDic[uniqueId];
        if self.showData.packType == Lua_PackDefine.TYPE_RUNSE then
            tvo = DataCenter.runesData:getRunesVoByUid(uniqueId);
        else
            tvo = DataCenter.packData:getItemVoByUnId(uniqueId);
        end
        if self.showData.batchType == 1 then -- 分解
            if tvo ~= nil and tvo.decompose ~= nil then
                for j = 1, #tvo.decompose do
                    local id = tvo.decompose[j][1];
                    local num = tvo.decompose[j][2];
                    if dic[id] == nil then
                        getVo = self.tvoArr[j];
                        if getVo == nil then
                            getVo = Lua_ToolVo.createToolVo(id);
                            self.tvoArr:add(getVo);
                        end
                        getVo:setData(id, count * num);
                        dic[id] = getVo;
                    else
                        dic[id].count = dic[id].count + count * num;
                    end
                end
            end
        elseif self.showData.batchType == 2 then -- 出售
            if tvo ~= nil and tvo.money_id > 0 then
                if dic[tvo.money_id] == nil then
                    getVo = self.tvoArr[1];
                    if getVo == nil then
                        getVo = Lua_ToolVo.createToolVo(tvo.money_id);
                        self.tvoArr:add(getVo);
                    end
                    getVo:setData(tvo.money_id, count * tvo.sys_price);
                    dic[tvo.money_id] = getVo;
                else
                    dic[tvo.money_id].count = dic[tvo.money_id].count + count * tvo.sys_price;
                end
            end
        end
    end

    local arr = Array();
    for k,v in pairs(dic) do
        arr:add(v)
    end
    len = arr:getSize();
    if self.getLen ~= len then -- 长度不同才修改显示区域大小
        self.getLen = len;
        if len > 5 then
            self.getList:setContentRect(620, 112);
        else
            self.getList:setContentRect(len * 112 + (len - 1 ) * 5, 112);
        end
    end
    self.getList:setArrayData(arr);
    self.getList.canDrag = not self.getList.bDragEnd;

    arr:clear();
    arr = nil;
    dic = nil;
end

function Lua_PackBatchWindow:onBtnFilterClick(go)
    if self.showData == nil or (self.clickTime ~= nil and getTime() - self.clickTime < 0.3) then
        return;
    end
    self.clickTime = getTime();

    Lua_WindowUtil.openWin("Lua_PackFilterWindow", Lua_WinParam.ACTION_OPEN, { packType = self.showData.packType, filterDic = self.filterDic});
end

function Lua_PackBatchWindow:onCheckHelp(go)
    local tipsData;
    if self.showData.batchType == 2 then
        tipsData = { des = LanUtil.getValue(309061), posX = 170, posY = -130, needAdapt = false };
    else
        tipsData = { des = LanUtil.getValue(309060), posX = 170, posY = -130, needAdapt = false };
    end
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_PackBatchWindow:onBtnOneKeyClick(go)
    if self.selectedCount >= self.totalCount then
        -- self.selectedDic = nil; self.selectedDic = {}; 都不能修改item中customParam的引用
        local len = self.selectedArr:getSize();
        local uniqueId;
        while len > 0 do
            uniqueId = self.selectedArr:remove();
            self.selectedDic[uniqueId] = nil;
            len = len - 1;
        end
    else
        local tvo;
        for i = 1, self.itemArr:getSize() do
            tvo = self.itemArr[i];
            if self.selectedDic[tvo.unique_id] == nil then
                self.selectedArr:add(tvo.unique_id);
            end
            self.selectedDic[tvo.unique_id] = tvo.count;
        end
    end

    self:updateShowList();
    self:updateGetList();
end

function Lua_PackBatchWindow:onBtnFuncClick(go)
    if self.selectedArr == nil or self.selectedArr:getSize() <= 0 then
        OperateAlert.showLangValue(309062);
        return;
    end

    if self.showData.batchType == 1 then -- 分解
        if self.showData.packType == Lua_PackDefine.TYPE_RUNSE then
            Lua_ProxyManager.getProxy("Lua_RunesProxy"):sDecomposeRunes(self.selectedDic);
        else
            Lua_ProxyManager.getProxy("Lua_PackProxy"):sOneKeyDecompose(self.selectedDic);
        end
    elseif self.showData.batchType == 2 then -- 出售
        Lua_ProxyManager.getProxy("Lua_PackProxy"):sOneKeySell(self.showData.packType, self.selectedDic);
    end
end




















Lua_PackBatchItem = class("Lua_PackBatchItem", Lua_ListCell);
function Lua_PackBatchItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_PackBatchItem:buildShowItem()
    self:superCall("buildShowItem");

    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setLocation(0, 10, 0);

    self.countText = UICreate.createLabel(self.content, nil, 0, -60, 100, 31, 20);
    self.countText.pivot = UIUtils.Pivot.Center;
    self.countText.alignmentValue = 4;
    self.countText.horizontalOverflowValue = 1;
    self.countText.colorStr = Lua_ColorDefine.transColor("846651");
end

function Lua_PackBatchItem:dispose()
    self:removeLessTimer();
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    self.customParam = nil;
    self.data = nil;
    self:superCall("dispose");
end

function Lua_PackBatchItem:setCustomParam(customParam)
    self.customParam = customParam;
end

function Lua_PackBatchItem:setData(data)
    self.data = data;

    self.itemIcon:setData(data);
    self.itemIcon:showNum(0);
    self:updateSelected();
end

function Lua_PackBatchItem:updateSelected()
    local count = self.customParam == nil and 0 or self.customParam[self.data.unique_id];
    self.selectedCount = count == nil and 0 or count;
    self.countText.text = self.selectedCount.."/"..self.data.count;
    if self.selectedCount > 0 then
        self.itemIcon:setMask(true);
        if self.btnLess == nil then
            self.btnLess = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_button_053_n", 28, 48, 0, 0);
            self.btnLess:addMousDownFuntion(self, self.onBtnLessClick);
            self.btnLess:addMouseUpFuntion(self, self.onBtnLessUpClick);
        end
        self.btnLess:setEnable(true);
    else
        self.itemIcon:setMask(false);
        if self.btnLess ~= nil then
            self.btnLess:setEnable(false);
        end
    end
end

function Lua_PackBatchItem:onPressClick()
    if self.data == nil then
        return;
    end
    if self.selectedCount >= self.data.count then
        DataCenter.packUtil:showItemInfo(self.data);
    end
    Lua_MsgUtil.callFunc("PACK_BATCH_PLUS", self.data);
end

function Lua_PackBatchItem:onLongPressClick()
    self:onPressClick();
end

function Lua_PackBatchItem:onBtnLessClick(go)
    if self.data == nil or self.selectedCount <= 0 then
        return;
    end
    self:startLessTimer();
end

function Lua_PackBatchItem:onBtnLessUpClick(go)
    if self.data == nil then
        return;
    end
    self:removeLessTimer();
end

function Lua_PackBatchItem:startLessTimer()
    if self.bLessTimer ~= true then
        self.bLessTimer = true;
        self.startLessTime = getTime();
        Lua_CommonUtil.addTimer("Lua_PackBatchItem", 0.01, self, self.onLessTimer);
    end
end

function Lua_PackBatchItem:removeLessTimer()
    if self.bLessTimer == true then
        self.bLessTimer = false;
        Lua_CommonUtil.removeTimer(self, self.onLessTimer);
        if not self.bLongPress then
            self:onLess();
        end
    end
end

function Lua_PackBatchItem:onLessTimer()
    if self.selectedCount <= 0 then
        self:removeLessTimer();
        return;
    end

    if getTime() - self.startLessTime > 0.3 then
        self.bLongPress = true;
        self:onLess();
    else
        self.bLongPress = false;
    end
end

function Lua_PackBatchItem:onLess()
    Lua_MsgUtil.callFunc("PACK_BATCH_LESS", self.data);
end