Lua_PackPanel = class("Lua_PackPanel", Lua_DisplayObject);
function Lua_PackPanel:ctor(p)
	self:superCall("ctor", p);
end

function Lua_PackPanel:buildPanel(go)
	self:superCall("buildPanel", go);
	self:initEvent();
end

function Lua_PackPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.line = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_line_003", 0, -273.5, 637, 17);

	self.btnDeco = UICreate.createButton(self.content, LanUtil.getValue(309001), -148, -325, 177, 58);
	self.btnDeco:setStyle(3);
	self.btnDeco.txt.colorStr = Lua_ColorDefine.transColorStr("7A6A5F");
	self.btnDeco:addClickFuntion(self, self.onBtnDecoClick);

	self.btnSell = UICreate.createButton(self.content, LanUtil.getValue(309002), 148, -325, 177, 58);
	self.btnSell:setStyle(1);
	self.btnSell.txt.colorStr = Lua_ColorDefine.transColorStr("8B5E34");
	self.btnSell:addClickFuntion(self, self.onBtnSellClick);

    self.itemList = Lua_DragList.new(self.content, 620, 635, Lua_AxisDefine.Vertical);
    self.itemList:setLocation(0, 68, 0);
    self.itemList:setListCell(Lua_PackItem, 112, 112, 5);
    self.itemList:setCellSpacing(15, 5);
end

function Lua_PackPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.itemArr ~= nil then
		self.itemArr:clear();
		self.itemArr = nil;
	end
	self.itemDic = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_PackPanel:initEvent()
	self:addLuaEvent("ADD_PACK_ITEMS", self, self.addItem);
	self:addLuaEvent("REMOVE_PACK_ITEMS", self, self.removeItem);

	self:addLuaEvent("RUNES_ATTR", self, self.updateRunesInfo);--符石重铸
	self:addLuaEvent("DELETE_RUNES_ITEM", self, self.updateRunesInfo);--符石更新

	self:addLuaEvent("EQUIP_FORGE", self, self.updateEquipInfo);--装备锻造
	self:addLuaEvent("DELETE_EQUIP_ITEM", self, self.updateEquipInfo);--装备删除
	self:addLuaEvent("EQUIP_RECAST_SURE", self, self.updateEquipInfo);--装备重铸
end

function Lua_PackPanel:setData(data)
	self.data = data;
	self:createButton();

	if self.itemArr == nil then
		self.itemArr = Array();
	else
		self.itemArr:clear();
	end
	self.itemDic = nil;
	if data.package == Lua_PackDefine.TYPE_EQUIP then
		self:updateListInfo(DataCenter.equipData.equipPackInfo);
	elseif data.package == Lua_PackDefine.TYPE_RUNSE then
		self:updateListInfo(DataCenter.runesData.runesPackInfo);
	else
		self.itemArr, self.itemDic = DataCenter.packData:getPackArrByPackType(data.package);
		self:updateListInfo(self.itemArr);
	end

	self.itemList:moveToIndex(1, true);
end

function Lua_PackPanel:createButton()
	local showDeco = false;
	local showSell = false;
	if self.data.btn_list ~= nil then
		for i = 1, #self.data.btn_list do
			if self.data.btn_list[i] == 1 then
				showDeco = true;
			elseif self.data.btn_list[i] == 2 then
				showSell = true;
			end
		end
	end

	if showDeco or showSell then
		self.itemList:setLocation(0, 68, 0);
		self.itemList:setContentRect(620, 635);
		self.line:setEnable(true);
	else
		self.itemList:setLocation(0, 10, 0);
		self.itemList:setContentRect(620, 755);
		self.line:setEnable(false);
	end
	
	self.btnDeco:setEnable(showDeco);
	self.btnSell:setEnable(showSell);
	if showDeco and not showSell then
		self.btnDeco:setLocation(0, -325, 0);
		self.btnDeco:setStyle(1);
	elseif not showDeco and showSell then
		self.btnSell:setLocation(0, -325, 0);
		self.btnSell:setStyle(1);
	else
		self.btnDeco:setLocation(-148, -325, 0);
		self.btnDeco:setStyle(3);
		self.btnSell:setLocation(148, -325, 0);
		self.btnSell:setStyle(1);
	end
end

function Lua_PackPanel:updateListInfo(arr)
	self:showNone(arr:getSize() <= 0);
	self.itemList:setArrayData(arr);
end

--符石数据更新
function Lua_PackPanel:updateRunesInfo()
	if not self.isActive or self.data == nil or self.data.package ~= Lua_PackDefine.TYPE_RUNSE then
		return;
	end

	self:updateListInfo(DataCenter.runesData.runesPackInfo);
end

--装备数据更新
function Lua_PackPanel:updateEquipInfo()
	if not self.isActive or self.data == nil or self.data.package ~= Lua_PackDefine.TYPE_EQUIP then
		return;
	end

	self:updateListInfo(DataCenter.equipData.equipPackInfo);
end


function Lua_PackPanel:showNone(bShow)
	if bShow then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, 53, 648, 119);
		end
		self.noneIcon:setEnable(true);

		if self.noneText == nil then
			self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(309000), 0, 53, 100, 40, 30);
			self.noneText.pivot = UIUtils.Pivot.Center;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("9F928C");
		end
		self.noneText:setEnable(true);
	else
		if self.noneIcon ~= nil then
			self.noneIcon:setEnable(false);
		end
		if self.noneText ~= nil then
			self.noneText:setEnable(false);
		end
	end
end

function Lua_PackPanel:addItem(msg)
	if not self.isActive or self.data == nil or msg.type ~= self.data.package then
		return;
	end

	local list = msg.item_list;
	local unique_id;
	local index;
	local len = self.itemArr:getSize();
	for i = 1, #list do
		unique_id = tonumber(list[i].unique_id);
		index = self.itemDic[unique_id];
		if index == nil then -- 新增道具
			self.itemArr:add(unique_id);
			len = self.itemArr:getSize();
			self.itemDic[unique_id] = len;
		end
	end
	
	self:showNone(len <= 0);
	self.itemList:setArrayData(self.itemArr);
end

function Lua_PackPanel:removeItem(msg)
	if not self.isActive or self.data == nil or msg.type ~= self.data.package then
		return;
	end


	local list = msg.item_list;
	local unique_id;
	local index;
	local tvo;
	local len = self.itemArr:getSize();
	for i = 1, #list do
		unique_id = tonumber(list[i].unique_id);
		index = self.itemDic[unique_id];
		if index ~= nil then
			tvo = DataCenter.packData:getItemVoByUnId(unique_id);
			if tvo == nil then -- 删除道具
				self.itemArr:remove(index);
				self.itemDic[unique_id] = nil;
				len = self.itemArr:getSize();
				for j = index, len do
					unique_id = self.itemArr[j];
					self.itemDic[unique_id] = j;
				end
			end
		end
	end

	self:showNone(len <= 0);
	self.itemList:setArrayData(self.itemArr);
end

function Lua_PackPanel:onBtnDecoClick(go)
	Lua_WindowUtil.openWin("Lua_PackBatchWindow", Lua_WinParam.ACTION_OPEN, { packType = self.data.package, batchType = 1 });
end

function Lua_PackPanel:onBtnSellClick(go)
	Lua_WindowUtil.openWin("Lua_PackBatchWindow", Lua_WinParam.ACTION_OPEN, { packType = self.data.package, batchType = 2 });
end




















Lua_PackItem = class("Lua_PackItem", Lua_ListCell);
function Lua_PackItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_PackItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_PackItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_PackItem:setData(data)
	self.data = data;
	if type(data) == "number" then
		if data == 0 then
			self.data = nil;
		else
			self.data = DataCenter.packData:getItemVoByUnId(data);
		end
	end

	self.itemIcon:setData(self.data);
	if self.data then
		if self.data.main_type == Lua_PackDefine.EQUIP then --装备展示叠加数量
			self.itemIcon:showNum(self.data.overlayCount);
		end
		self.itemIcon:showUseLogo(self.data.use_logo == 1);
	end
end

function Lua_PackItem:onPressClick()
	if self.data == nil or self.data.id == nil then
		return;
	end
	DataCenter.packUtil:showItemInfo(self.data, true, false);
end

function Lua_PackItem:onMouseDownHandle()
	self.itemIcon:setScale(0.95, 0.95, 0.95);
end

function Lua_PackItem:onMouseUpHandle()
	self.itemIcon:setScale(1, 1, 1);
end