Lua_PackWindow = class("Lua_PackWindow", Lua_Window);
function Lua_PackWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_PackWindow";
    self.skinName = "PackWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
end

function Lua_PackWindow:buildShowItem()
    self:superCall("buildShowItem");

    self:addLuaEvent("PACK_TYPE_SELECT", self, self.onPackTypeSelect);
    self.panelDic = {};
    self.packArr = DataCenter.packData:getPackTagList();

    self.btnList = Lua_DragList.new(self.content, 668, 70, Lua_AxisDefine.Horizontal);
    self.btnList:setLocation(0, -425, 0);
    self.btnList.canDrag = self.packArr:getSize() > 5;
    self.btnList:setListCell(Lua_PackTypeItem, 133.6, 70, 1);
    self.btnList:setArrayData(self.packArr);
end

function Lua_PackWindow:dispose()
    if self.panelDic ~= nil then
        for k,v in pairs(self.panelDic) do
            v:dispose();
        end
        self.panelDic = nil;
    end
    self.showPanel = nil;
    if self.btnList ~= nil then
        self.btnList:dispose();
        self.btnList = nil;
    end
    self.packArr = nil;
    self:superCall("dispose");
end

function Lua_PackWindow:showWin(param)
    local packType;
    if type(param) == "table" then
        packType = param.main_id;
    elseif type(param) == "number" then
        packType = param;
    end

    local index;
    for i = 1, self.packArr:getSize() do
        if self.packArr[i].package == packType then
            index = i;
            break;
        end
    end
    index = index == nil and 1 or index;
    self.btnList:moveToIndex(index, true);
    self.btnList:setSelectClick(index);
    self.btnList:setSelected(index);
end

function Lua_PackWindow:onPackTypeSelect(data)
    if self.selectedType == data.package or strIsNullOrEmpty(data.panel_name) then
        return;
    end
    self.selectedType = data.package;

    for k,v in pairs(self.panelDic) do
        v:setEnable(false);
    end

    if self.panelDic[data.panel_name] == nil then
        local showPanel = checkRequire(data.panel_name);
        self.panelDic[data.panel_name] = showPanel.new(self.content);
    end

    self.showPanel = self.panelDic[data.panel_name];
    self.showPanel:setEnable(true);
    self.showPanel:setData(data);
end




















Lua_PackTypeItem = class("Lua_PackTypeItem", Lua_ListCell);
function Lua_PackTypeItem:ctor(p)
    self:superCall("ctor", p, "PackTypeItem_skin");
end

function Lua_PackTypeItem:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_PackTypeItem:dispose()
    if self.redPointIcon ~= nil then
        self.redPointIcon:dispose();
        self.redPointIcon = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_PackTypeItem:setData(data)
    self.data = data;
    if data == nil then
        return;
    end
    
    self.btnName.text = data.name;
    self:setRedPoint(data.red_point_id);
end

function Lua_PackTypeItem:setRedPoint(id)
    if strIsNullOrEmpty(id) then
        if self.redPointIcon ~= nil then
            self.redPointIcon:changeRedPoint(nil);
        end
    else
        if self.redPointIcon == nil then
            self.redPointIcon = Lua_RedPointIcon.new(self.content);
            self.redPointIcon:setLocation(50, 20);
        end
        self.redPointIcon:changeRedPoint(id);
    end
end

function Lua_PackTypeItem:onSelectionChange(bSelect)
    self:superCall("onSelectionChange", bSelect);
    self.btnBg:setEnable(bSelect);
    if bSelect then
        self.btnName.colorStr = Lua_ColorDefine.transColorStr("8B5E34");
        self.btnName:setLocation(0, 8, 0);
    else
        self.btnName.colorStr = Lua_ColorDefine.transColorStr("5C504B");
        self.btnName:setLocation(0, -2, 0);
    end
end

function Lua_PackTypeItem:onPressClick()
    if self.data == nil then
        return;
    end
    Lua_MsgUtil.callFunc("PACK_TYPE_SELECT", self.data);
    return true;
end